#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="__init__.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from __future__ import absolute_import

# import apis into api package
from AsposeEmailCloudSdk.api.ai_bcr_api import AiBcrApi
from AsposeEmailCloudSdk.api.ai_name_api import AiNameApi
from AsposeEmailCloudSdk.api.calendar_api import CalendarApi
from AsposeEmailCloudSdk.api.client_account_api import ClientAccountApi
from AsposeEmailCloudSdk.api.client_folder_api import ClientFolderApi
from AsposeEmailCloudSdk.api.client_message_api import ClientMessageApi
from AsposeEmailCloudSdk.api.client_thread_api import ClientThreadApi
from AsposeEmailCloudSdk.api.contact_api import ContactApi
from AsposeEmailCloudSdk.api.disposable_email_api import DisposableEmailApi
from AsposeEmailCloudSdk.api.email_api import EmailApi
from AsposeEmailCloudSdk.api.email_config_api import EmailConfigApi
from AsposeEmailCloudSdk.api.file_api import FileApi
from AsposeEmailCloudSdk.api.folder_api import FolderApi
from AsposeEmailCloudSdk.api.mapi_calendar_api import MapiCalendarApi
from AsposeEmailCloudSdk.api.mapi_contact_api import MapiContactApi
from AsposeEmailCloudSdk.api.mapi_message_api import MapiMessageApi
from AsposeEmailCloudSdk.api.storage_api import StorageApi

# EmailCloud imports
from AsposeEmailCloudSdk.api.mapi_group import MapiGroup
from AsposeEmailCloudSdk.api.client_group import ClientGroup
from AsposeEmailCloudSdk.api.ai_group import AiGroup
from AsposeEmailCloudSdk.api.cloud_storage_group import CloudStorageGroup
from AsposeEmailCloudSdk.api.email_cloud import EmailCloud
